@@ -13,7 +13,7 @@ use Exporter ();
 
 use Validation::Class::Prototype;
 
-our $VERSION = '7.900034'; # VERSION
+our $VERSION = '7.900035'; # VERSION
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(
@@ -517,29 +517,24 @@ Validation::Class - Powerful Data Validation Framework
 
 =head1 VERSION
 
-version 7.900034
+version 7.900035
 
 =head1 SYNOPSIS
 
     use Validation::Class::Simple::Streamer;
 
-    my $input = Validation::Class::Simple::Streamer->new($parameters);
+    my  $input = Validation::Class::Simple::Streamer->new($parameters);
 
-    # data validation rules for the username parameter
+        # check username parameter
+        $input->check('username')->required->between('5-255');
+        $input->filters([qw/trim strip/]);
 
-    $input->check('username')->required->between('5-255');
-    $input->filters([qw/trim strip/]);
+        # check password parameter
+        $input->check('password')->required->between('5-255')->min_symbols(1);
+        $input->filters([qw/trim strip/]);
 
-    # data validation rule for the password parameter
-
-    $input->check('password')->required->between('5-255')->min_symbols(1);
-    $input->filters([qw/trim strip/]);
-
-    # perform validation
-
-    unless ($input) {
-        # handle the failures
-    }
+        # run validations
+        print $input->errors_to_string unless $input;
 
 =head1 DESCRIPTION
 
@@ -792,7 +787,7 @@ The process of applying roles, requirement, and other settings to the current
 class mainly involves introspecting the namespace's methods and merging relevant
 parts of the prototype configuration.
 
-=head2 load:classes
+=head2 load-classes
 
 The `classes` (or class) option uses L<Module::Find> to load all child classes
 (in-all-subdirectories) for convenient access through the
@@ -813,7 +808,7 @@ application. This option accepts an arrayref or single argument.
 
     1;
 
-=head2 load:requirements
+=head2 load-requirements
 
     package MyApp::User;
 
@@ -843,7 +838,7 @@ option accepts an arrayref or single argument.
 
     1;
 
-=head2 load:roles
+=head2 load-roles
 
     package MyApp::Person;
 
@@ -1173,12 +1168,6 @@ See L<Validation::Class::Prototype/error_fields> for full documentation.
 
 See L<Validation::Class::Prototype/errors> for full documentation.
 
-head2 errors_to_string
-
-    $self->errors_to_string;
-
-See L<Validation::Class::Prototype/errors_to_string> for full documentation.
-
 =head2 get_errors
 
     $self->get_errors;
@@ -1336,6 +1325,12 @@ See L<Validation::Class::Prototype/validate_method> for full documentation.
 
 See L<Validation::Class::Prototype/validate_profile> for full documentation.
 
+=head2 errors_to_string
+
+    $self->errors_to_string;
+
+See L<Validation::Class::Prototype/errors_to_string> for full documentation.
+
 =head1 EXTENSIBILITY
 
 Validation::Class does NOT provide method modifiers but can be easily extended
